# remirepo spec file for php-zstd
#
# Copyright (c) 2018-2023 Remi Collet
# License: CC-BY-SA-4.0
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#

%{?scl:%scl_package php-zstd}

%bcond_without tests
%bcond_without apcu
%bcond_without libzstd

%global zstdver 1.5.5

%global pecl_name   zstd
%global with_zts    0%{!?_without_zts:%{?__ztsphp:1}}
%global ini_name    40-%{pecl_name}.ini
%global buildver    %(pkg-config --silence-errors --modversion libzstd 2>/dev/null || echo 65536)
%global sources     %{pecl_name}-%{version}
%global _configure  ../%{sources}/configure

Summary:       Zstandard extension
Name:          %{?scl_prefix}php-%{pecl_name}
Version:       0.12.3
Release:       3%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
%if %{with libzstd}
License:       MIT
%else
# bundled library is BSD-3-Clause
License:       MIT AND BSD-3-Clause
%endif
URL:           https://pecl.php.net/package/%{pecl_name}
Source0:       https://pecl.php.net/get/%{pecl_name}-%{version}%{?prever}.tgz

BuildRequires: %{?dtsprefix}gcc
BuildRequires: %{?scl_prefix}php-devel >= 7.0
%if %{with apcu}
BuildRequires: %{?scl_prefix}php-pecl-apcu-devel
%endif
BuildRequires: %{?scl_prefix}php-pear
%if %{with libzstd}
BuildRequires: libzstd-devel   >= 1.4
Requires:      libzstd%{?_isa} >= %{buildver}
%else
Provides:      bundled(libzstd) = %{zstdver}
%endif

Requires:      %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:      %{?scl_prefix}php(api) = %{php_core_api}

Provides:       %{?scl_prefix}php-pecl-%{pecl_name}          = %{version}
Provides:       %{?scl_prefix}php-pecl-%{pecl_name}%{?_isa}  = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})         = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}


%description
PHP extension for compression and decompression with Zstandard library.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%package devel
Summary:       %{name} developer files (header)
Requires:      %{name}%{?_isa} = %{version}-%{release}
Requires:      %{?scl_prefix}php-devel%{?_isa}
Provides:      %{?scl_prefix}php-%{pecl_name}-devel = %{version}-%{release}
Provides:      %{?scl_prefix}php-%{pecl_name}-devel%{?_isa} = %{version}-%{release}

%description devel
These are the files needed to compile programs using %{name}.


%prep
%setup -qc

%{?_licensedir:sed -e '/LICENSE/s/role="doc"/role="src"/' -i package.xml}

cd %{sources}
%if %{with libzstd}
# Use the system library
rm -r zstd
sed -e '\:"zstd/:d' -i ../package.xml
%else
cp zstd/LICENSE LICENSE-libzstd
%endif

# Sanity check, really often broken
extver=$(sed -n '/#define PHP_ZSTD_VERSION/{s/.* "//;s/".*$//;p}' php_zstd.h)
if test "x${extver}" != "x%{version}%{?gh_date:-dev}"; then
   : Error: Upstream extension version is ${extver}, expecting %{version}%{?gh_date:-dev}.
   exit 1
fi
cd ..

mkdir NTS
%if %{with_zts}
mkdir ZTS
%endif

# Drop in the bit of configuration
cat << 'EOF' | tee %{ini_name}
; Enable '%{summary}' extension module
extension = %{pecl_name}.so
EOF


%build
%{?dtsenable}

cd %{sources}
%{__phpize}

cd ../NTS
%configure \
    --with-php-config=%{__phpconfig} \
%if %{with libzstd}
    --with-libzstd \
%endif
    --with-libdir=%{_lib} \
    --enable-zstd
make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
%configure \
    --with-php-config=%{__ztsphpconfig} \
%if %{with libzstd}
    --with-libzstd \
%endif
    --with-libdir=%{_lib} \
    --enable-zstd
make %{?_smp_mflags}
%endif


%install
%{?dtsenable}

# Install the NTS stuff
make -C NTS install INSTALL_ROOT=%{buildroot}
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
# Install the ZTS stuff
make -C ZTS install INSTALL_ROOT=%{buildroot}
install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Test & Documentation
for i in $(grep 'role="test"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do [ -f %{sources}/tests/$i ] && install -Dpm 644 %{sources}/tests/$i %{buildroot}%{pecl_testdir}/%{pecl_name}/tests/$i
done
for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 %{sources}/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done



%check
cd %{sources}

export REPORT_EXIT_STATUS=1
%if %{with libzstd}
ver=$(pkg-config libzstd --modversion)
if [ "$ver" != "%{zstdver}" ] ; then
export REPORT_EXIT_STATUS=0
fi
%endif

: Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with apcu}
: Check that apcu is aware of zstd serializer
%{__php} --no-php-ini \
    --define extension=apcu.so \
    --define apc.enabled=1 \
    --define apc.enable_cli=1 \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --ri apcu | grep '%{pecl_name}'
%endif

%if %{with tests}
: Upstream test suite  for NTS extension
TEST_PHP_EXECUTABLE=%{__php} \
TEST_PHP_ARGS="-n -d extension=%{buildroot}%{php_extdir}/%{pecl_name}.so" \
%{__php} -n run-tests.php -q --offline --show-diff
%endif

%if %{with_zts}
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with tests}
: Upstream test suite  for ZTS extension
TEST_PHP_EXECUTABLE=%{__ztsphp} \
TEST_PHP_ARGS="-n -d extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so" \
%{__ztsphp} -n run-tests.php -q --offline --show-diff
%endif
%endif


%files
%{?_licensedir:%license %{sources}/LICENSE}
%doc %{pecl_docdir}/%{pecl_name}
%{pecl_xmldir}/%{name}.xml
%if ! %{with libzstd}
%{?_licensedir:%license %{sources}/LICENSE-libzstd}
%endif

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%files devel
%doc %{sources}/tests
%{php_incldir}/ext/%{pecl_name}

%if %{with_zts}
%{php_ztsincldir}/ext/%{pecl_name}
%endif


%changelog
* Wed Aug 30 2023 Remi Collet <remi@remirepo.net> - 0.12.3-3
- rebuild for PHP 8.3.0RC1

* Tue Jul 18 2023 Remi Collet <remi@remirepo.net> - 0.12.3-2
- build out of sources tree

* Sat Apr 29 2023 Remi Collet <remi@remirepo.net> - 0.12.3-1
- update to 0.12.3
- drop patch merged upstream

* Fri Apr 28 2023 Remi Collet <remi@remirepo.net> - 0.12.2-1
- update to 0.12.2
- fix extension version and build warnings, using patch from
  https://github.com/kjdev/php-ext-zstd/pull/57

* Mon Jan 23 2023 Remi Collet <remi@remirepo.net> - 0.12.1-1
- update to 0.12.1

* Tue Nov 22 2022 Remi Collet <remi@remirepo.net> - 0.12.0-1
- update to 0.12.0

* Mon Oct  4 2021 Remi Collet <remi@remirepo.net> - 0.11.0-1
- update to 0.11.0

* Wed Apr 28 2021 Remi Collet <remi@remirepo.net> - 0.10.0-2
- F34 rebuild for https://github.com/remicollet/remirepo/issues/174

* Fri Jan 22 2021 Remi Collet <remi@remirepo.net> - 0.10.0-1
- update to 0.10.0
- drop patch merged upstream
- enable apcu serializer with PHP 7+

* Wed Sep 30 2020 Remi Collet <remi@remirepo.net> - 0.9.0-4
- rebuild for PHP 8.0.0RC1
- add patch from https://github.com/kjdev/php-ext-zstd/pull/35

* Wed Sep  2 2020 Remi Collet <remi@remirepo.net> - 0.9.0-3
- rebuild for PHP 8.0.0beta3

* Wed Aug  5 2020 Remi Collet <remi@remirepo.net> - 0.9.0-2
- rebuild for 8.0.0beta1

* Thu Jun  4 2020 Remi Collet <remi@remirepo.net> - 0.9.0-1
- update to 0.9.0 (stable)

* Fri May 29 2020 Remi Collet <remi@remirepo.net> - 0.8.1-1
- update to 0.8.1 with libzstd 1.4.5
- drop patch merged upstream

* Wed Apr 15 2020 Remi Collet <remi@remirepo.net> - 0.8.0-2
- fix test suite with PHP 8 using patch from
  https://github.com/kjdev/php-ext-zstd/pull/31

* Fri Feb  7 2020 Remi Collet <remi@remirepo.net> - 0.8.0-1
- update to 0.8.0 with system libzstd 1.4.4

* Mon Dec 23 2019 Remi Collet <remi@remirepo.net> - 0.7.7-1
- update to 0.7.7
- sources from pecl

* Fri Dec 20 2019 Remi Collet <remi@remirepo.net> - 0.7.5-1
- update to 0.7.5 with bundled libzstd 1.4.4

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 0.7.4-2
- rebuild for 7.4.0RC1

* Tue Aug 27 2019 Remi Collet <remi@remirepo.net> - 0.7.4-1
- update to 0.7.4 with bundled libzstd 1.4.3
- drop patch merged upstream

* Wed Jul 24 2019 Remi Collet <remi@remirepo.net> - 0.7.3-4
- add patch for 7.4.0beta1 from
  https://github.com/kjdev/php-ext-zstd/pull/24

* Tue Jul 23 2019 Remi Collet <remi@remirepo.net> - 0.7.3-3
- rebuild for 7.4.0beta1

* Fri May 31 2019 Remi Collet <remi@remirepo.net> - 0.7.3-2
- rebuild using system libzstd, as 1.4.0 is now available

* Wed Apr 24 2019 Remi Collet <remi@remirepo.net> - 0.7.3-1
- update to 0.7.3

* Tue Apr 23 2019 Remi Collet <remi@remirepo.net> - 0.7.2-1
- update to 0.7.2
- use bundled libzstd 1.4.0

* Fri Apr 19 2019 Remi Collet <remi@remirepo.net> - 0.7.1-1
- update to 0.7.1

* Tue Apr 16 2019 Remi Collet <remi@remirepo.net> - 0.7.0-1
- update to 0.7.0

* Mon Apr 15 2019 Remi Collet <remi@remirepo.net> - 0.6.1-2
- test build for Stream implementation, from
  https://github.com/kjdev/php-ext-zstd/pull/17

* Thu Apr  4 2019 Remi Collet <remi@remirepo.net> - 0.6.1-1
- update to 0.6.1

* Tue Mar 26 2019 Remi Collet <remi@remirepo.net> - 0.6.0-1
- update to 0.6.0

* Mon Jan  7 2019 Remi Collet <remi@remirepo.net> - 0.5.0-1
- update to 0.5.0

* Thu Aug 16 2018 Remi Collet <remi@remirepo.net> - 0.4.14-4
- ignore test suite results with newer system library

* Thu Aug 16 2018 Remi Collet <remi@remirepo.net> - 0.4.14-3
- rebuild for 7.3.0beta2 new ABI

* Wed Jul 18 2018 Remi Collet <remi@remirepo.net> - 0.4.14-2
- rebuild for 7.3.0alpha4 new ABI

* Tue Jun 19 2018 Remi Collet <remi@remirepo.net> - 0.4.14-1
- update to 0.4.14

* Mon Apr  9 2018 Remi Collet <remi@remirepo.net> - 0.4.13-1
- update to 0.4.13

* Wed Jan 31 2018 Remi Collet <remi@remirepo.net> - 0.4.12-1
- update to 0.4.12 (no change, PR merged upstream)

* Tue Jan 30 2018 Remi Collet <remi@remirepo.net> - 0.4.11-1
- new package, version 0.4.11
- add patch to build with system libzstd from
  https://github.com/kjdev/php-ext-zstd/pull/7
